@@ -38,6 +38,7 @@ def process_common_arguments(args):
   '''return True if should stop'''
   processors = [
     slogconf.exc_info,
+    slogconf.filter_exc,
   ]
   logger_factory = None
 
@@ -189,7 +190,7 @@ class Source:
       else:
         conf = config[name]
         if not conf.getboolean('missing_ok', False):
-          logger.warn('no-result', name=name)
+          logger.warning('no-result', name=name)
         self.on_no_result(name)
 
     if self.newver:
