@@ -15,7 +15,9 @@ try:
 except ImportError:
   pycurl = None
 
-__all__ = ['session', 'HTTPError']
+from .httpclient import DEFAULT_USER_AGENT
+
+__all__ = ['session', 'HTTPError', 'NetworkErrors']
 
 client = AsyncHTTPClient()
 HTTP2_AVAILABLE = None if pycurl else False
@@ -51,6 +53,7 @@ class Session:
       q = urlencode(params)
       url += '?' + q
 
+    kwargs.setdefault("headers", {}).setdefault('User-Agent', DEFAULT_USER_AGENT)
     r = HTTPRequest(url, **kwargs)
     return ResponseManager(r)
 
@@ -64,7 +67,7 @@ class ResponseManager:
   async def __aexit__(self, exc_type, exc, tb):
     pass
 
-async def json_response(self):
+async def json_response(self, **kwargs):
   return json.loads(self.body.decode('utf-8'))
 
 async def read(self):
@@ -73,3 +76,5 @@ async def read(self):
 HTTPResponse.json = json_response
 HTTPResponse.read = read
 session = Session()
+
+NetworkErrors = ()
